function SetupSREyelinkToolbox()
fprintf('\n');
fprintf(['This script will create a backup of the files to be replaced by the EyelinkToolbox version\n' ...
    'that is installed with the current version of the EyeLink Developers Kit\n']);
fprintf(['If you have any important & non-standard files created within the PsychtoolboxRoot installation\n' ...
    'directory, please backup your files manually before continuinging for additional security\n\n']);

answer=input('To continue now, please confirm y/yes to overwrite or n/no to cancel>> ','s');
if ~strcmpi(answer,'yes') && ~strcmpi(answer,'y')
    fprintf('You didn''t say "y" or "yes", so I''m taking it as no.\n');
    return;
end

if ~exist(['.' filesep() 'Psychtoolbox']) || ~exist(['.' filesep() 'EyelinkToolbox-Documentation.html'])
    error('Before running this script, please change directories to where SetupSREyelinkToolbox.m was installed with the EyeLink Developers Kit. This is required, so the updated version of the EyelinkToolbox can be copied from the correct relative path into your <PsychtoolboxRoot>.');
end

try
    PsychtoolboxVersion;
catch
    error('A test call to PsychtoolboxVersion as unsuccessful. Please make sure to install Psychtoolbox before running this script and updating EyelinkToolbox from the installed EyeLink Developers Kit.');
end


wd = pwd;
wdSource = [wd, filesep() 'Psychtoolbox'];

etbRoot = [ ...
    'PsychHardware', filesep(), ...
    'EyelinkToolbox', filesep(), ...
    ];

etbDemos = [etbRoot 'EyelinkDemos'];
etbBasic = [etbRoot 'EyelinkBasic'];

pbRoot = [ ...
    'PsychBasic', filesep() ...
    ];

mexFiles = { ...
    'Octave3LinuxFiles64/Eyelink.mex', ...
    'Octave5LinuxFiles64/Eyelink.mex', ...
    'Eyelink.mexa64', ...
    'MatlabWindowsFilesR2007a/Eyelink.mexw64', ...
    'Octave6OSXFiles64/Eyelink.mex', ...
    'Octave6WindowsFiles64/Eyelink.mex', ...
    'Eyelink.mexmaci64'
    };
mexFiles = regexprep(mexFiles, '/', filesep);
mexFiles = cellfun(@(x) [pbRoot, x], mexFiles, 'UniformOutput', false);

zipTarget = [PsychtoolboxRoot, 'sr-etb-backup.zip'];
zipSource = { ...
    [etbRoot 'EyelinkBasic'], ...
    [etbRoot 'EyelinkDemos'], ...
    mexFiles{:} ...
    };

fprintf( ...
    ['The following files and directories will be backed up to a zip file prior to being replaced with\n' ...
    'the EyelinkToolbox revisions provided with the EyeLink Developers Kit:\n']);
cellfun(@(x) fprintf('\t%s\n', x), zipSource);
fprintf('The zip file will be saved to:\n\t%s\n', zipTarget);
if exist(zipTarget)
    fprintf('\n');
    answer=input('This .zip file currently exists, please confirm y/yes to overwrite or n/no to cancel>> ','s');
    if ~strcmpi(answer,'yes') && ~strcmpi(answer,'y')
        fprintf('You didn''t say "y" or "yes", so I''m taking it as no.\n');
        return;
    end
    fprintf('Confirmed, %s will be overwritten with a new archive.\n', zipTarget);
end

fprintf('\n');
answer=input('To continue creating .zip file backup confirm with y/yes, or to skip .zip backup n/no. To exit press ctrl+c>> ','s');
if ~strcmpi(answer,'no') && ~strcmpi(answer,'n')
    fprintf('You didn''t say "n" or "no", so I''m taking it as yes.\nCreating .zip backup.\n');
    er = [];
    try
        zip(zipTarget, ...
            zipSource, ...
            PsychtoolboxRoot ...
            )
        fprintf('Created: %s\n', zipTarget);
    catch er
        warning(er.getReport);
    end
    if ~isempty(er)
        fprintf('Creating the .zip file failed, see message above.\n');
        answer=input('To continue without creating a .zip backup confirm with y/yes, or n/no to cancel and exit>> ','s');
        if ~strcmpi(answer,'yes') && ~strcmpi(answer,'y')
            fprintf('You didn''t say "y" or "yes", so I''m taking it as no.\n');
            return;
        end
    end
else
    fprintf('Skippig creating of .zip backup.\n');
end


qn = sprintf([ ...
    'Do you wish to continue, and replace the currently installed EyelinkToolbox' ...
    'installed here:\n\t%s\n' ...
    'with the contents from the EyeLink Developers Kit' ...
    'from here:\n\t%s\n'
    ], ...
    PsychtoolboxRoot, wdSource...
    );

fprintf('\n');
answer=input('Please confirm y/yes to proceed or n/no to cancel installation>> ', 's');
if ~strcmpi(answer,'yes') && ~strcmpi(answer,'y')
    fprintf('You didn''t say "y" or "yes", so I''m taking it as no.\n');
    return;
end
fprintf('Confirmed, %s will be overwritten with a new archive.\n', zipTarget);

rs = recycle;
recycle('on');
cellfun(@(x) delete([PsychtoolboxRoot x]), mexFiles)
try, rmdir([PsychtoolboxRoot etbDemos], 's'); end
try, rmdir([PsychtoolboxRoot etbBasic], 's'); end
recycle(rs);

er = [];
try
    copyfile(wdSource, PsychtoolboxRoot)
catch er
    error('failed to copy EyelinkToolbox files from installed EyeLink Developers Kit into <PsychtoolboxRoot>. Please ee the error message above, and if required contact support@sr-research.com.');
end

fprintf('Success copying new files.\nSetupPsychtoolbox() needs to run again to apply the changes.')
fprintf('\n');
answer=input('To run SetupPsychtoolbox(), please confirm y/yes to update your Psychtoolbox installation now, or n/no to cancel>> ','s');
if ~strcmpi(answer,'yes') && ~strcmpi(answer,'y')
    fprintf('You didn''t say "y" or "yes", so I''m taking it as no.\n');
    return;
end

cd(PsychtoolboxRoot);
SetupPsychtoolbox();

end